@@ -14,17 +14,15 @@ import Graphics.Gloss.Internals.Interface.Backend
 
 
 -- | Open a new window and display the given picture.
---
---   Use the following commands once the window is open:
---
---      * Quit - esc-key.
---      * Move Viewport - left-click drag, arrow keys.
---      * Rotate Viewport - right-click drag, control-left-click drag, or home\/end-keys.
---      * Zoom Viewport - mouse wheel, or page up\/down-keys.
---
 display :: Display          -- ^ Display mode.
         -> Color            -- ^ Background color.
         -> Picture          -- ^ The picture to draw.
         -> IO ()
 
-display = displayWithBackend defaultBackendState
+display dis backColor picture
+        = displayWithBackend
+                defaultBackendState
+                dis
+                backColor
+                (return picture)
+                (const (return ()))
